/* $Id: colors.c,v 1.57 2010/09/17 12:57:36 lamonte Exp $
 *
 * colors.c
 *
 * Additional acknowledgements, news, and updates to the Qodem Project
 * are available at http://qodem.sourceforge.net .
 *
 * This module is licensed under the GNU General Public License Version 2.
 * Please see the file "COPYING" in this directory for more information
 * about the GNU General Public License Version 2.
 *
 *     Copyright (C) 2003  Kevin Lamonte
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 */

#include "common.h"
#include "qcurses.h"
#include <stdlib.h>
#include <string.h>
#include "input.h"
#include "colors.h"

/*
 * The color pair number that is white foreground black background.
 *
 * On the raw Linux console, this will be 0.  But most X11-based
 * terminal emulators support lots of colors, so I can define my
 * own white-on-black color pair number; this is handy to always
 * really get white-on-black for terminals that have a different
 * default color.
 */
unsigned int q_white_color_pair_num;

/*
 * I try to initialize 64 curses colors, representing all the
 * combinations of red, green, and blue foreground and backgrounds.
 * This will give half of the PC color set.  The A_BOLD gives the
 * other half.
 */
static short pc_to_curses_map[] = {
	COLOR_BLACK,
	COLOR_BLUE,
	COLOR_GREEN,
	COLOR_CYAN,
	COLOR_RED,
	COLOR_MAGENTA,

	/* Really brown */
	COLOR_YELLOW,

	/* Really light gray */
	COLOR_WHITE

	/* Bold colors:
	dark gray
	light blue
	light green
	light cyan
	light red
	light magenta
	yellow
	white
	*/
};

/* Global colormap table */
struct q_text_color_struct q_text_colors[Q_COLOR_MAX];

/*
 * q_setup_colors - load default colors, then override with user preferences
 */
void q_setup_colors() {
	int i;
	const attr_t COLOR_DEFAULT = COLOR_BLACK;

	q_text_colors[Q_COLOR_STATUS].bold		= Q_FALSE;
	q_text_colors[Q_COLOR_STATUS].fg		= COLOR_BLUE;
	q_text_colors[Q_COLOR_STATUS].bg		= COLOR_WHITE;

	q_text_colors[Q_COLOR_STATUS_DISABLED].bold		= Q_TRUE;
	q_text_colors[Q_COLOR_STATUS_DISABLED].fg		= COLOR_BLACK;
	q_text_colors[Q_COLOR_STATUS_DISABLED].bg		= COLOR_WHITE;

	q_text_colors[Q_COLOR_CONSOLE].bold		= Q_TRUE;
	q_text_colors[Q_COLOR_CONSOLE].fg		= COLOR_CYAN;
	q_text_colors[Q_COLOR_CONSOLE].bg		= COLOR_DEFAULT;

	q_text_colors[Q_COLOR_CONSOLE_TEXT].bold	= Q_FALSE;
	q_text_colors[Q_COLOR_CONSOLE_TEXT].fg		= COLOR_WHITE;
	q_text_colors[Q_COLOR_CONSOLE_TEXT].bg		= COLOR_DEFAULT;

	q_text_colors[Q_COLOR_CONSOLE_BACKGROUND].bold	= Q_FALSE;
	q_text_colors[Q_COLOR_CONSOLE_BACKGROUND].fg	= COLOR_DEFAULT;
	q_text_colors[Q_COLOR_CONSOLE_BACKGROUND].bg	= COLOR_BLACK;

	q_text_colors[Q_COLOR_WINDOW_BORDER].bold	= Q_TRUE;
	q_text_colors[Q_COLOR_WINDOW_BORDER].fg		= COLOR_BLUE;
	q_text_colors[Q_COLOR_WINDOW_BORDER].bg		= COLOR_BLACK;

	q_text_colors[Q_COLOR_WINDOW].bold		= Q_FALSE;
	q_text_colors[Q_COLOR_WINDOW].fg		= COLOR_DEFAULT;
	q_text_colors[Q_COLOR_WINDOW].bg		= COLOR_BLUE;

	q_text_colors[Q_COLOR_MENU_COMMAND].bold	= Q_TRUE;
	q_text_colors[Q_COLOR_MENU_COMMAND].fg		= COLOR_YELLOW;
	q_text_colors[Q_COLOR_MENU_COMMAND].bg		= COLOR_BLUE;

	q_text_colors[Q_COLOR_MENU_COMMAND_UNAVAILABLE].bold		= Q_TRUE;
	q_text_colors[Q_COLOR_MENU_COMMAND_UNAVAILABLE].fg		= COLOR_BLACK;
	q_text_colors[Q_COLOR_MENU_COMMAND_UNAVAILABLE].bg		= COLOR_BLUE;

	q_text_colors[Q_COLOR_MENU_TEXT].bold		= Q_FALSE;
	q_text_colors[Q_COLOR_MENU_TEXT].fg		= COLOR_WHITE;
	q_text_colors[Q_COLOR_MENU_TEXT].bg		= COLOR_BLUE;

	q_text_colors[Q_COLOR_WINDOW_FIELD_HIGHLIGHTED].bold		= Q_FALSE;
	q_text_colors[Q_COLOR_WINDOW_FIELD_HIGHLIGHTED].fg		= COLOR_WHITE;
	q_text_colors[Q_COLOR_WINDOW_FIELD_HIGHLIGHTED].bg		= COLOR_BLUE;

	q_text_colors[Q_COLOR_WINDOW_FIELD_TEXT_HIGHLIGHTED].bold	= Q_TRUE;
	q_text_colors[Q_COLOR_WINDOW_FIELD_TEXT_HIGHLIGHTED].fg		= COLOR_YELLOW;
	q_text_colors[Q_COLOR_WINDOW_FIELD_TEXT_HIGHLIGHTED].bg		= COLOR_BLUE;

	q_text_colors[Q_COLOR_PHONEBOOK_ENTRY].bold	= Q_FALSE;
	q_text_colors[Q_COLOR_PHONEBOOK_ENTRY].fg	= COLOR_WHITE;
	q_text_colors[Q_COLOR_PHONEBOOK_ENTRY].bg	= COLOR_BLUE;

	q_text_colors[Q_COLOR_PHONEBOOK_SELECTED].bold	= Q_FALSE;
	q_text_colors[Q_COLOR_PHONEBOOK_SELECTED].fg	= COLOR_WHITE;
	q_text_colors[Q_COLOR_PHONEBOOK_SELECTED].bg	= COLOR_BLACK;

	q_text_colors[Q_COLOR_PHONEBOOK_SELECTED_TAGGED].bold	= Q_TRUE;
	q_text_colors[Q_COLOR_PHONEBOOK_SELECTED_TAGGED].fg	= COLOR_YELLOW;
	q_text_colors[Q_COLOR_PHONEBOOK_SELECTED_TAGGED].bg	= COLOR_BLACK;

	q_text_colors[Q_COLOR_PHONEBOOK_TAGGED].bold	= Q_TRUE;
	q_text_colors[Q_COLOR_PHONEBOOK_TAGGED].fg	= COLOR_YELLOW;
	q_text_colors[Q_COLOR_PHONEBOOK_TAGGED].bg	= COLOR_BLUE;

	q_text_colors[Q_COLOR_SCRIPT_RUNNING].bold	= Q_TRUE;
	q_text_colors[Q_COLOR_SCRIPT_RUNNING].fg	= COLOR_GREEN;
	q_text_colors[Q_COLOR_SCRIPT_RUNNING].bg	= COLOR_BLUE;

	q_text_colors[Q_COLOR_SCRIPT_FINISHED].bold	= Q_TRUE;
	q_text_colors[Q_COLOR_SCRIPT_FINISHED].fg	= COLOR_RED;
	q_text_colors[Q_COLOR_SCRIPT_FINISHED].bg	= COLOR_BLUE;

	q_text_colors[Q_COLOR_SCRIPT_FINISHED_OK].bold	= Q_TRUE;
	q_text_colors[Q_COLOR_SCRIPT_FINISHED_OK].fg	= COLOR_YELLOW;
	q_text_colors[Q_COLOR_SCRIPT_FINISHED_OK].bg	= COLOR_BLUE;
	
	/* TODO: Remove these before 1.0.0 */

	q_text_colors[Q_COLOR_MENU_NOTIMPL].bold	= Q_TRUE;
	q_text_colors[Q_COLOR_MENU_NOTIMPL].fg		= COLOR_BLACK;
	q_text_colors[Q_COLOR_MENU_NOTIMPL].bg		= COLOR_BLUE;

	q_text_colors[Q_COLOR_MENU_OBSOLETE].bold	= Q_FALSE;
	q_text_colors[Q_COLOR_MENU_OBSOLETE].fg		= COLOR_RED;
	q_text_colors[Q_COLOR_MENU_OBSOLETE].bg		= COLOR_BLUE;

	/* Initialize the 64 curses colors.  I'm lazy:  if the display
	can't support all of them (e.g. monochrome) I just stop. */

	for (i=1; (i<64) && (i<COLOR_PAIRS); i++) {
		init_pair(i, ((i & 0x38) >> 3), (i & 0x07));
	}

	/* Special case: put black-on-black at 0x38 */
	init_pair(0x38, 0x00, 0x00);

	if (COLOR_PAIRS > 64) {
		/* Make my own white-on-black color */
		init_pair(64, COLOR_WHITE, 0x00);
		q_white_color_pair_num = 64;
	} else {
		/* Assume color pair 0 is white on black */
		assume_default_colors(COLOR_WHITE, 0x00);
		q_white_color_pair_num = 0;
	}

} /* ---------------------------------------------------------------------- */

/* Up to 256 characters for the HTML/CSS color tag */
static char font_color[256];

/*
 * color_to_html - Turn a bitmask'd color into an HTML <font color> string.
 */
char * color_to_html(const attr_t color) {
	char * font_weight = "normal";
	char * text_decoration = "none";
	char * fg_text;
	char * bg_text;

	char * bitmask_to_html_map[] = {
		"#000000",		/* COLOR_BLACK   */
		"#AB0000",		/* COLOR_RED     */
		"#00AB00",		/* COLOR_GREEN   */
		"#996600",		/* COLOR_YELLOW  */
		"#0000AB",		/* COLOR_BLUE    */
		"#990099",		/* COLOR_MAGENTA */
		"#009999",		/* COLOR_CYAN    */
		"#ABABAB",		/* COLOR_WHITE   */
	};

	char * bitmask_to_html_map_bright[] = {
		"#545454",		/* COLOR_BLACK   */
		"#FF6666",		/* COLOR_RED     */
		"#66FF66",		/* COLOR_GREEN   */
		"#FFFF66",		/* COLOR_YELLOW  */
		"#6666FF",		/* COLOR_BLUE    */
		"#FF66FF",		/* COLOR_MAGENTA */
		"#66FFFF",		/* COLOR_CYAN    */
		"#FFFFFF",		/* COLOR_WHITE   */
	};

	short fg;
	short bg;

	fg = PAIR_NUMBER(color) >> 3;
	bg = PAIR_NUMBER(color) & 0x07;

	memset(font_color, 0, sizeof(font_color));

	if ((color & A_BLINK) && (color & A_UNDERLINE)) {
		text_decoration = "blink, underline";
	} else if (color & A_UNDERLINE) {
		text_decoration = "underline";
	} else if (color & A_BLINK) {
		text_decoration = "blink";
	}
	if (color & A_REVERSE) {
		fg_text = bitmask_to_html_map[bg];
		if (color & A_BOLD) {
			bg_text = bitmask_to_html_map_bright[fg];
		} else {
			bg_text = bitmask_to_html_map[fg];
		}
	} else {
		bg_text = bitmask_to_html_map[bg];
		if (color & A_BOLD) {
			fg_text = bitmask_to_html_map_bright[fg];
		} else {
			fg_text = bitmask_to_html_map[fg];
		}
	}

	sprintf(font_color, "style=\"color: %s; background-color: %s; text-decoration: %s; font-weight: %s\"",
		fg_text, bg_text, text_decoration, font_weight);

	return font_color;
} /* ---------------------------------------------------------------------- */

/* Thank you to TheDraw 4.63! */

/*
 * convert_thedraw_screen - convert a screen created with TheDraw's
 *                         "C" output format into a list of
 *                          struct q_scrolline_struct's.
 */
void convert_thedraw_screen(const unsigned char * screen, const int length, struct q_scrolline_struct * output_line) {
	int i;
	attr_t bold;
	short fg;
	short bg;
	short curses_color;

	output_line->length = 0;

	for (i = 0; i < length; i += 2) {
		/* First byte: character */
		output_line->chars[output_line->length] = screen[i];

		/* Second byte: PC color */
		bold = A_NORMAL;
		fg = screen[i+1] & 0x07;
		if ((screen[i+1] & 0x08) != 0) {
			bold = A_BOLD;
		}
		bg = (screen[i+1] >> 4) & 0x07;
		fg = pc_to_curses_map[fg];
		bg = pc_to_curses_map[bg];

		curses_color = (fg << 3) | bg;

		output_line->colors[output_line->length] = (bold | COLOR_PAIR(curses_color));
		output_line->length++;

		/* Wrap if necessary */
		if (output_line->length == 80) {
			struct q_scrolline_struct * new_line = (struct q_scrolline_struct *)Xmalloc(sizeof(struct q_scrolline_struct), __FILE__, __LINE__);
			memset(new_line, 0, sizeof(struct q_scrolline_struct));
			new_line->prev = output_line;
			output_line->next = new_line;
			output_line = output_line->next;
		}
	}
} /* ---------------------------------------------------------------------- */

#if 1

/*
 * New splash screen.
 */

unsigned char q_info_screen [] = {
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x1B,  '', 0x1B,
    '', 0x1B,  '', 0x1B,  '', 0x1B,  '', 0x1B,  '', 0x1B,  '', 0x1B,
    '', 0x1B,  '', 0x1B,  '', 0x1B,  '', 0x1B,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x1B,  ' ', 0x1B,  ' ', 0x1B,  '', 0x1B,  '', 0x1B,  '', 0x1B,
    '', 0x1B,  '', 0x1B,  '', 0x1B,  ' ', 0x1B,  ' ', 0x1B,  '', 0x1B,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x1B,  ' ', 0x1B,  ' ', 0x1B,  '', 0x1B,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x1B,  ' ', 0x1B,
    ' ', 0x1B,  '', 0x1B,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x1B,  ' ', 0x1B,
    ' ', 0x1B,  '', 0x1B,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x1B,  ' ', 0x1B,  ' ', 0x1B,  '', 0x1B,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x1B,  ' ', 0x1B,  ' ', 0x1B,  '', 0x1B,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x1B,  ' ', 0x1B,  ' ', 0x1B,  '', 0x1B,
    '', 0x09,  '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,
    '', 0x0A,  '', 0x0A,  '', 0x09,  '', 0x0A,  '', 0x0A,  '', 0x0A,
    '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x09,  '', 0x09,  '', 0x0A,
    '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,
    '', 0x09,  '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,
    '', 0x0A,  '', 0x0A,  '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x1B,  ' ', 0x1B,  ' ', 0x1B,  '', 0x1B,
    '', 0x09,  '', 0x1B,  '', 0x1B,  '', 0x1B,  '', 0x1B,  ' ', 0x1B,
    ' ', 0x1B,  '', 0x1B,  '', 0x09,  '', 0x0A,  ' ', 0x0A,  '', 0x0A,
    '', 0x0A,  '', 0x0A,  ' ', 0x0A,  '', 0x0A,  '', 0x09,  '', 0x0A,
    ' ', 0x0A,  '', 0x0A,  '', 0x0A,  ' ', 0x0A,  '', 0x0A,  '', 0x0A,
    '', 0x09,  '', 0x0A,  ' ', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,
    '', 0x0A,  '', 0x0A,  '', 0x09,  '', 0x0A,  ' ', 0x0A,  '', 0x0A,
    ' ', 0x0A,  '', 0x0A,  ' ', 0x0A,  '', 0x0A,  '', 0x09,  '', 0x08,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x1B,  ' ', 0x1B,
    ' ', 0x1B,  '', 0x1B,  '', 0x1B,  '', 0x1B,  ' ', 0x1B,  '', 0x1B,
    '', 0x1B,  ' ', 0x1B,  ' ', 0x1B,  '', 0x1B,  '', 0x09,  '', 0x0A,
    ' ', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,  ' ', 0x0A,  '', 0x0A,
    '', 0x09,  '', 0x0A,  ' ', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,
    ' ', 0x0A,  '', 0x0A,  '', 0x09,  '', 0x0A,  ' ', 0x0A,  '', 0x0A,
    '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x09,  '', 0x0A,
    ' ', 0x0A,  '', 0x0A,  ' ', 0x0A,  '', 0x0A,  ' ', 0x0A,  '', 0x0A,
    '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x1B,  '', 0x1B,  '', 0x1B,  '', 0x1B,  '', 0x1B,  '', 0x1B,
    '', 0x1B,  ' ', 0x1B,  '', 0x1B,  '', 0x1B,  '', 0x1B,  '', 0x1B,
    '', 0x09,  '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,
    '', 0x0A,  '', 0x0A,  '', 0x09,  '', 0x0A,  '', 0x0A,  '', 0x0A,
    '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x09,  '', 0x0A,
    '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,
    '', 0x09,  '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,  '', 0x0A,
    '', 0x0A,  '', 0x0A,  '', 0x09,  '', 0x08,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x1B,  '', 0x1B,  '', 0x1B,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,
    '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x09,  '', 0x08,
    '', 0x09,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08};

#else

/*
 * Original splash screen, a scrape (THEGRAB.EXE) from Qmodem(tm) 5.01.
 *
 * I liked that one, but we're pretty far away from Qmodem(tm) now,
 * and I don't want my users to see this homage to Qmodem(tm) in a
 * negative way.
 *
 */

unsigned char q_info_screen [] = {
    '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,
    '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,
    '', 0x7F,  '', 0x7F,  '', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  '', 0x78,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,
    '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,
    '', 0x7F,  '', 0x7F,  '', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x1F,
    'Q', 0x1F,  'o', 0x1F,  'd', 0x1F,  'e', 0x1F,  'm', 0x1F,  ' ', 0x1F,

/* VERSION is HERE |
		   V   */

    '0', 0x1F,  '.', 0x1F,  '3', 0x1F,  '.', 0x1F,  '2', 0x1F,  ' ', 0x1F,

/*                 ^
   VERSION is here | */


    'O', 0x1F,  'p', 0x1F,  'e', 0x1F,  'n', 0x1F,  '-', 0x1F,  'S', 0x1F,
    'o', 0x1F,  'u', 0x1F,  'r', 0x1F,  'c', 0x1F,  'e', 0x1F,  ' ', 0x1F,
    'T', 0x1F,  'e', 0x1F,  'r', 0x1F,  'm', 0x1F,  'i', 0x1F,  'n', 0x1F,
    'a', 0x1F,  'l', 0x1F,  ' ', 0x1F,  '', 0x78,  '', 0x78,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x7F,  '', 0x7F,
    '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,
    '', 0x7F,  '', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x1F,  'h', 0x1F,  't', 0x1F,  't', 0x1F,  'p', 0x1F,
    ':', 0x1F,  '/', 0x1F,  '/', 0x1F,  'q', 0x1F,  'o', 0x1F,  'd', 0x1F,
    'e', 0x1F,  'm', 0x1F,  '.', 0x1F,  's', 0x1F,  'o', 0x1F,  'u', 0x1F,
    'r', 0x1F,  'c', 0x1F,  'e', 0x1F,  'f', 0x1F,  'o', 0x1F,  'r', 0x1F,
    'g', 0x1F,  'e', 0x1F,  '.', 0x1F,  'n', 0x1F,  'e', 0x1F,  't', 0x1F,
    ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x0F,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,
    '', 0x7F,  '', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,
    ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,
    ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,
    ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,
    ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,
    ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,  ' ', 0x1F,
    ' ', 0x1F,  ' ', 0x0F,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,
    '', 0x7F,  '', 0x7F,  '', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,
    ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,
    ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,
    ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,
    ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,
    ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x7F,  '', 0x7F,
    '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  '', 0x78,  '', 0x78,
    '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,
    '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,
    '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,
    '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,
    '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x08,  '', 0x08,
    '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  '', 0x78,  '', 0x78,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x7F,  '', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    '', 0x78,  '', 0x78,  ' ', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  '', 0x78,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  '', 0x78,  '', 0x78,  ' ', 0x78,  '', 0x78,  '', 0x78,
    ' ', 0x78,  '', 0x78,  '', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  '', 0x78,  '', 0x78,  ' ', 0x78,
    '', 0x78,  ' ', 0x78,  '', 0x78,  '', 0x78,  ' ', 0x78,  ' ', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  '', 0x78,  '', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  '', 0x78,  ' ', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,
    ' ', 0x78,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  ' ', 0x78,  ' ', 0x78,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  '', 0x7F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  '', 0x78,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  ' ', 0x78,  '', 0x7F,  '', 0x3F,
    '', 0x03,  '', 0x03,  '', 0x03,  '', 0x03,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x03,  '', 0x03,  '', 0x03,  ' ', 0x33,  '', 0x3F,  '', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  '', 0x78,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  ' ', 0x78,  ' ', 0x78,  '', 0x7F,  '', 0x3F,
    '', 0x03,  '', 0x03,  '', 0x03,  '', 0x03,  '', 0x3F,  '', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  '', 0x7F,  '', 0x3F,  '', 0x03,  '', 0x03,
    '', 0x03,  '', 0x03,  '', 0x3F,  '', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  '', 0x78,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  ' ', 0x78,  '', 0x3F,
    '', 0x03,  '', 0x03,  '', 0x03,  '', 0x03,  '', 0x3F,  '', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    '', 0x7F,  '', 0x3F,  '', 0x03,  '', 0x03,  '', 0x03,  '', 0x03,
    '', 0x0F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  '', 0x78,  '', 0x78,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x70,
    ' ', 0x70,  '', 0x3F,  '', 0x03,  '', 0x03,  '', 0x03,  '', 0x3F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  '', 0x3F,  ' ', 0x3F,
    '', 0x03,  '', 0x03,  '', 0x0F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  '', 0x48,  '', 0x78,  '', 0x04,  '', 0x04,
    '', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,  '', 0x08,  '', 0x04,
    '', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,  '', 0x48,  '', 0x48,
    '', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,
    '', 0x08,  '', 0x04,  '', 0x04,  '', 0x04,  '', 0x48,  '', 0x04,
    '', 0x04,  '', 0x04,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,
    '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,
    ' ', 0x0F,  ' ', 0x0F,  ' ', 0x78,  '', 0x3F,  '', 0x03,  '', 0x03,
    '', 0x03,  '', 0x3F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    '', 0x3F,  '', 0x03,  '', 0x03,  '', 0x03,  '', 0x0F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  '', 0x48,  '', 0x48,  '', 0x78,
    '', 0x04,  '', 0x04,  ' ', 0x04,  '', 0x08,  '', 0x04,  '', 0x04,
    ' ', 0x04,  '', 0x04,  '', 0x04,  ' ', 0x04,  '', 0x08,  '', 0x04,
    '', 0x04,  ' ', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,
    '', 0x04,  '', 0x04,  '', 0x08,  '', 0x04,  '', 0x04,  '', 0x04,
    '', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,  ' ', 0x04,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,
    '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,
    '', 0x78,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x78,  '', 0x3F,
    '', 0x03,  '', 0x03,  '', 0x03,  '', 0x3F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,
    '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  '', 0x3F,  '', 0x03,  '', 0x03,  '', 0x03,
    '', 0x0F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  '', 0x48,  '', 0x48,
    '', 0x48,  '', 0x78,  '', 0x04,  '', 0x04,  ' ', 0x04,  '', 0x08,
    '', 0x04,  '', 0x04,  ' ', 0x04,  '', 0x04,  '', 0x04,  ' ', 0x04,
    '', 0x08,  '', 0x04,  '', 0x04,  ' ', 0x04,  '', 0x04,  '', 0x04,
    '', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,  ' ', 0x04,  '', 0x04,
    '', 0x04,  ' ', 0x04,  '', 0x04,  ' ', 0x04,  '', 0x04,  '', 0x04,
    ' ', 0x04,  '', 0x08,  '', 0x08,  '', 0x78,  '', 0x78,  '', 0x78,
    '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,
    '', 0x78,  '', 0x78,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,
    ' ', 0x78,  '', 0x3F,  '', 0x03,  '', 0x03,  '', 0x03,  '', 0x3F,
    ' ', 0x7F,  '', 0x7F,  '', 0x3F,  '', 0x3F,  '', 0x03,  '', 0x03,
    '', 0x03,  '', 0x03,  '', 0x03,  '', 0x03,  '', 0x03,  '', 0x03,
    '', 0x3F,  '', 0x3F,  '', 0x7F,  ' ', 0x7F,  '', 0x3F,  '', 0x03,
    '', 0x03,  '', 0x03,  '', 0x0F,  ' ', 0x7F,  ' ', 0x7F,  '', 0x48,
    '', 0x48,  '', 0x48,  '', 0x48,  '', 0x78,  '', 0x04,  '', 0x04,
    '', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,  ' ', 0x04,  '', 0x04,
    '', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,  ' ', 0x04,
    '', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,  '', 0x04,
    '', 0x08,  '', 0x04,  '', 0x04,  ' ', 0x04,  '', 0x08,  '', 0x08,
    '', 0x04,  '', 0x04,  ' ', 0x04,  '', 0x08,  '', 0x08,  '', 0x78,
    '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,
    '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  ' ', 0x0F,  ' ', 0x0F,
    ' ', 0x0F,  ' ', 0x0F,  ' ', 0x78,  '', 0x3F,  '', 0x03,  '', 0x03,
    '', 0x03,  '', 0x03,  '', 0x3F,  '', 0x3F,  '', 0x03,  '', 0x3F,
    '', 0x3F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x7F,
    '', 0x7F,  '', 0x3F,  '', 0x3F,  '', 0x03,  '', 0x03,  '', 0x3F,
    '', 0x3F,  '', 0x03,  '', 0x03,  '', 0x03,  '', 0x3F,  ' ', 0x7F,
    '', 0x48,  '', 0x48,  '', 0x48,  '', 0x48,  '', 0x48,  '', 0x78,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,
    '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  '', 0x78,  ' ', 0x0F,
    ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x78,  ' ', 0x78,
    '', 0x7F,  '', 0x3F,  '', 0x03,  '', 0x03,  '', 0x03,  '', 0x03,
    '', 0x3F,  '', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  '', 0x7F,  '', 0x3F,
    '', 0x03,  '', 0x03,  '', 0x03,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x48,  '', 0x0F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x0F,  ' ', 0x0F,
    ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  '', 0x7F,  '', 0x3F,
    ' ', 0x3F,  ' ', 0x3F,  '', 0x03,  '', 0x03,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x03,  '', 0x03,  '', 0x3F,  '', 0x3F,  '', 0x3F,  ' ', 0x3F,
    ' ', 0x3F,  '', 0x03,  '', 0x03,  '', 0x03,  '', 0x03,  '', 0x03,
    '', 0x03,  '', 0x3F,  '', 0x48,  '', 0x0F,  ' ', 0x3F,  ' ', 0x3F,
    ' ', 0x3F,  '', 0x3A,  ' ', 0x3A,  ' ', 0x3A,  ' ', 0x3A,  ' ', 0x3A,
    '', 0x00,  ' ', 0x30,  ' ', 0x30,  ' ', 0x30,  ' ', 0x30,  '', 0x3A,
    ' ', 0x3A,  ' ', 0x3A,  ' ', 0x3A,  ' ', 0x3A,  '', 0x3A,  ' ', 0x3A,
    ' ', 0x3A,  ' ', 0x3A,  ' ', 0x3A,  '', 0x00,  ' ', 0x30,  ' ', 0x30,
    ' ', 0x30,  ' ', 0x30,  '', 0x3A,  ' ', 0x3A,  ' ', 0x3A,  ' ', 0x3A,
    ' ', 0x3A,  '', 0x00,  ' ', 0x30,  ' ', 0x30,  ' ', 0x30,  '', 0x3E,
    '', 0x7E,  '', 0x7E,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,
    ' ', 0x0F,  ' ', 0x0F,  ' ', 0x7E,  ' ', 0x7E,  ' ', 0x7E,  ' ', 0x7E,
    ' ', 0x7E,  ' ', 0x7E,  '', 0x7F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x7F,
    ' ', 0x7F,  '', 0x7F,  '', 0x7F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x48,  '', 0x0F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,  '', 0x3F,
    '', 0x3F,  '', 0x3F,  '', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,
    ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x0F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,
    ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  ' ', 0x7F,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x70,  '', 0x70,  '', 0x70,  '', 0x70,  '', 0x70,  '', 0x70,
    ' ', 0x70,  ' ', 0x70,  ' ', 0x70,  ' ', 0x70,  ' ', 0x70,  ' ', 0x70,
    ' ', 0x70,  ' ', 0x70,  ' ', 0x70,  ' ', 0x70,  ' ', 0x70,  ' ', 0x70,
    ' ', 0x70,  ' ', 0x70,  ' ', 0x70,  ' ', 0x70,  ' ', 0x70,  ' ', 0x70,
    ' ', 0x70,  ' ', 0x70,  ' ', 0x70,  ' ', 0x70,  ' ', 0x70,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,  '', 0x08,
    '', 0x08,  '', 0x70,  '', 0x70,  '', 0x70,  '', 0x70,  '', 0x70,
    '', 0x70,  '', 0x70};

#endif
