/* $Id: dialer.c,v 1.72 2010/10/07 19:18:29 lamonte Exp $
 *
 * dialer.c
 *
 * Additional acknowledgements, news, and updates to the Qodem Project
 * are available at http://qodem.sourceforge.net .
 *
 * This module is licensed under the GNU General Public License Version 2.
 * Please see the file "COPYING" in this directory for more information
 * about the GNU General Public License Version 2.
 *
 *     Copyright (C) 2003  Kevin Lamonte
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 */

#include "common.h"

/* Use forkpty() */
#ifdef __APPLE__
#include <util.h>
#else
#ifdef __FreeBSD__
#include <sys/types.h>
#include <libutil.h>
#else
#include <pty.h>
#endif
#endif /* __APPLE__ */

#ifdef __linux
#include <sys/ioctl.h>
#endif /* __linux */

#include <stdio.h>
#include <errno.h>
#include <string.h>			/* strdup() */
#include <sys/types.h>
#include <unistd.h>
#include <ctype.h>
#include <stdlib.h>
#include <signal.h>
#include <assert.h>
#include <termios.h>
#include <fcntl.h>
#include "qodem.h"
#include "screen.h"
#include "emulation.h"
#include "music.h"
#include "states.h"
#include "status.h"
#include "options.h"
#include "scrollback.h"
#include "phonebook.h"
#include "script.h"
#include "dialer.h"

/* When we started dialing */
time_t q_dialer_start_time;

/* How much time is left (in seconds) on the cycle clock */
time_t q_dialer_cycle_time;

/* When the cycle clock started */
time_t q_dialer_cycle_start_time;

/* How many calls have been attempted */
int q_dialer_attempts;

/* The status line to report on the redialer screen */
char q_dialer_status_message[DIALOG_MESSAGE_SIZE];

/* The modem line to report on the redialer screen */
char q_dialer_modem_message[DIALOG_MESSAGE_SIZE];

/* Our current dialing state */
Q_DIAL_STATE q_dial_state;

/*
 * tokenize_command - Separate command into arguments.
 */
char ** tokenize_command(const char * argv) {
	int i, j;
	int argv_start;
	char ** new_argv;
	char * old_argv;
	int n;

	old_argv = Xstrdup(argv, __FILE__, __LINE__);
	n = strlen(argv);

	/* Trim beginning whitespace */
	argv_start = 0;
	while (isspace(argv[argv_start])) {
		argv_start++;
	}

	for (i=0, j=argv_start; j<n; i++) {
		while (!isspace(argv[j]) && (j<n)) {
			j++;
		}
		while (isspace(argv[j]) && (j<n)) {
			j++;
		}
	}

	/* i is the # of tokens */
	new_argv = (char **)Xmalloc(sizeof(char *) * (i+1), __FILE__, __LINE__);
	for (i=0, j=argv_start; j<n; i++) {
		new_argv[i] = old_argv + j;
		while (!isspace(old_argv[j]) && (j<n)) {
			j++;
		}
		while (isspace(old_argv[j]) && (j<n)) {
			old_argv[j] = 0;
			j++;
		}
	}

	/*
	 * Why can't I free this?  Because new_argv is pointers
	 * into old_argv.  Freeing it kills the child process.
	 */
	/* Xfree(old_argv, __FILE__, __LINE__); */

	new_argv[i] = NULL;
	return new_argv;
} /* ---------------------------------------------------------------------- */

/*
 * connect_command - construct the command line
 */
static char * connect_command(const struct q_phone_struct * target) {
	char connect_string[COMMAND_LINE_SIZE];

	switch (target->method) {

	case Q_DIAL_METHOD_SHELL:
		snprintf(connect_string, sizeof(connect_string), "%s", get_option(Q_OPTION_SHELL));
		break;
	case Q_DIAL_METHOD_SSH:
		if ((q_status.current_username != NULL) && (wcslen(q_status.current_username) > 0)) {
			snprintf(connect_string, sizeof(connect_string), "%s", get_option(Q_OPTION_SSH_USER));
		} else {
			snprintf(connect_string, sizeof(connect_string), "%s", get_option(Q_OPTION_SSH));
		}
		break;
	case Q_DIAL_METHOD_RSH:
		if ((q_status.current_username != NULL) && (wcslen(q_status.current_username) > 0)) {
			snprintf(connect_string, sizeof(connect_string), "%s", get_option(Q_OPTION_RSH_USER));
		} else {
			snprintf(connect_string, sizeof(connect_string), "%s", get_option(Q_OPTION_RSH));
		}
		break;
	case Q_DIAL_METHOD_RLOGIN:
		if ((q_status.current_username != NULL) && (wcslen(q_status.current_username) > 0)) {
			snprintf(connect_string, sizeof(connect_string), "%s", get_option(Q_OPTION_RLOGIN_USER));
		} else {
			snprintf(connect_string, sizeof(connect_string), "%s", get_option(Q_OPTION_RLOGIN));
		}
		break;
	case Q_DIAL_METHOD_TELNET:
		snprintf(connect_string, sizeof(connect_string), "%s", get_option(Q_OPTION_TELNET));
		break;
	/*
	case Q_DIAL_METHOD_TN3270:
		snprintf(connect_string, sizeof(connect_string), "%s", get_option(Q_OPTION_TN3270));
		break;
	 */
	case Q_DIAL_METHOD_COMMANDLINE:
		snprintf(connect_string, sizeof(connect_string), "%s", target->address);
		break;

	case Q_DIAL_METHOD_MODEM:
		/* NOP */
		return NULL;
	}

	/* $USERNAME */
	char * substituted_string;
	if (q_status.current_username != NULL) {
		substituted_string = substitute_wcs_half(connect_string, "$USERNAME", q_status.current_username);
		strncpy(connect_string, substituted_string, sizeof(connect_string));
		Xfree(substituted_string, __FILE__, __LINE__);
	}

	/* $REMOTEHOST */
	if (q_status.remote_address != NULL) {
		substituted_string = substitute_string(connect_string, "$REMOTEHOST", q_status.remote_address);
		strncpy(connect_string, substituted_string, sizeof(connect_string));
		Xfree(substituted_string, __FILE__, __LINE__);
	}

	/* $REMOTEPORT */
	if (q_status.remote_port != NULL) {
		substituted_string = substitute_string(connect_string, "$REMOTEPORT", q_status.remote_port);
		strncpy(connect_string, substituted_string, sizeof(connect_string));
		Xfree(substituted_string, __FILE__, __LINE__);
	}

	return Xstrdup(connect_string, __FILE__, __LINE__);
} /* ---------------------------------------------------------------------- */

#if 0

#define termios_check_flag(A, B, C)		\
	if (term->A & B) { \
		fprintf(file, "%s ", C); \
	}

/*
 * Debugging the termios structure
 */
static void show_termios_info(const struct termios * term) {
	FILE * file = fopen("debug_termios.txt", "w");

	fprintf(file, "c_iflag: ");
	termios_check_flag(c_iflag, IGNBRK, "IGNBRK");
	termios_check_flag(c_iflag, IGNPAR, "IGNPAR");
	termios_check_flag(c_iflag, BRKINT, "BRKINT");
	termios_check_flag(c_iflag, PARMRK, "PARMRK");
	termios_check_flag(c_iflag, INPCK, "INPCK");
	termios_check_flag(c_iflag, ISTRIP, "ISTRIP");
	termios_check_flag(c_iflag, INLCR, "INLCR");
	termios_check_flag(c_iflag, IGNCR, "IGNCR");
	termios_check_flag(c_iflag, ICRNL, "ICRNL");
	termios_check_flag(c_iflag, IUCLC, "IUCLC");
	termios_check_flag(c_iflag, IXON, "IXON");
	termios_check_flag(c_iflag, INPCK, "IXANY");
	termios_check_flag(c_iflag, IXOFF, "IXOFF");
	termios_check_flag(c_iflag, IMAXBEL, "IMAXBEL");
	fprintf(file, "\n");

	fprintf(file, "c_lflag: ");
	termios_check_flag(c_lflag, ISIG, "ISIG");
	termios_check_flag(c_lflag, ICANON, "ICANON");

	fprintf(file, "\n");
	fclose(file);
} /* ---------------------------------------------------------------------- */

#endif

/*
 * Perform a cfmakeraw() on the TTY
 */
Q_BOOL set_raw_termios(const int tty_fd) {
	struct termios old_termios;
	struct termios new_termios;

	if (tcgetattr(tty_fd, &old_termios) < 0) {
		/* Error */
		return Q_FALSE;
	}
	memcpy(&new_termios, &old_termios, sizeof(struct termios));
	cfmakeraw(&new_termios);
	if (tcsetattr(tty_fd, TCSANOW, &new_termios) < 0) {
		/* Error */
		return Q_FALSE;
	}

	/* All OK */
	return Q_TRUE;
} /* ---------------------------------------------------------------------- */

/*
 * Make the file/socket non-blocking
 */
Q_BOOL set_nonblock(const int fd) {
	int flags;

	flags = fcntl(fd, F_GETFL);
	if (fcntl(fd, F_SETFL, flags | O_NONBLOCK) < 0) {
		/* Error */
		return Q_FALSE;
	}

	/* All OK */
	return Q_TRUE;
} /* ---------------------------------------------------------------------- */

/*
 * dial_out - dial out to a target system
 *
 * NOTE: ANY CHANGES TO BEHAVIOR HERE MUST BE CHECKED IN
 * script_start() ALSO!!!
 */
int dial_out(struct q_phone_struct * target) {
	pid_t child_pid = -1;

	char ** target_argv;

	/* Assert that the connection does not already exist. */
	assert(q_child_tty_fd == -1);

	/* Reset clock for keepalive/idle timeouts */
	time(&q_data_sent_time);

	if (target->method == Q_DIAL_METHOD_MODEM) {
		/*
		 * Modem dialup:  just open the serial port and switch
		 * to Q_STATE_DIALER.
		 */
		qlog(_("Dialing %ls (%s)...\n"), target->name, target->address);
		if (open_serial_port() == Q_TRUE) {
			time(&q_dialer_cycle_start_time);
			q_dialer_cycle_time = atoi(get_option(Q_OPTION_DIAL_CONNECT_TIME));
			q_dialer_attempts++;
			q_dial_state = Q_DIAL_DIALING;

			/* Set the message */
			sprintf(q_dialer_status_message, _("%-3d Seconds remain until Cycle"), (int)q_dialer_cycle_time);

			switch_state(Q_STATE_DIALER);
		}

	} else {

		/*
		 * Other connection methods:  fork and execute
		 */

		/*
		 * Push all the data out to clear the soon-to-be child process's
		 * output buffer.
		 */
		screen_flush();

		char * command = connect_command(target);

		/*
		 * Log the command line.  This should be in the child branch
		 * but putting it there corrupts the session log output (two
		 * file handles pointing to the same file).
		 */
		qlog(_("[child] Connecting with command line '%s'...\n"), command);

		/* Fork and put the child on a new tty */
		char ttyname_buffer[FILENAME_SIZE];
		child_pid = forkpty(&q_child_tty_fd, ttyname_buffer, NULL, NULL);
		q_child_ttyname = Xstrdup(ttyname_buffer, __FILE__, __LINE__);

		if (child_pid == 0) {
			/*
			 * Child process, will become the connection program
			 */

			/*
			 * NOTE: ANY CHANGES TO BEHAVIOR HERE MUST BE CHECKED IN
			 * script_start() ALSO!!!
			 */

			struct q_scrolline_struct * line;
			struct q_scrolline_struct * line_next;
			/* This just has to be long enough for LINES=blah and COLUMNS=blah */
			char buffer[32];
			int columns;

			/* Restore signal handlers */
			signal(SIGPIPE, SIG_DFL);

			/* Free scrollback memory */
			line = q_scrollback_buffer;
			while (line != NULL) {
				line_next = line->next;
				Xfree(line, __FILE__, __LINE__);
				line = line_next;
			}

			/* Set my TERM variable */
			switch (target->emulation) {
			case Q_EMUL_ANSI:
				putenv("TERM=ansi");
				break;
			case Q_EMUL_AVATAR:
				putenv("TERM=avatar");
				break;
			case Q_EMUL_VT52:
				putenv("TERM=vt52");
				break;
			case Q_EMUL_VT100:
				putenv("TERM=vt100");
				break;
			case Q_EMUL_VT102:
				putenv("TERM=vt102");
				break;
			case Q_EMUL_VT220:
				putenv("TERM=vt220");
				break;
			case Q_EMUL_TTY:
				putenv("TERM=dumb");
				break;
			case Q_EMUL_LINUX:
			case Q_EMUL_LINUX_UTF8:
				putenv("TERM=linux");
				break;
			case Q_EMUL_XTERM:
			case Q_EMUL_XTERM_UTF8:
				putenv("TERM=xterm");
				break;
			case Q_EMUL_DEBUG:
				/* No default terminal setting */
				putenv("TERM");
				break;
			}

			/* Set LINES and COLUMNS */
			memset(buffer, 0, sizeof(buffer));
			snprintf(buffer, sizeof(buffer), "LINES=%u", HEIGHT - STATUS_HEIGHT);
			putenv(strdup(buffer));
			memset(buffer, 0, sizeof(buffer));

			switch (target->emulation) {
			case Q_EMUL_ANSI:
			case Q_EMUL_AVATAR:
			case Q_EMUL_TTY:
				/* BBS-ish emulations:  check the assume_80_columns flag */
				if (q_status.assume_80_columns == Q_TRUE) {
					columns = 80;
				} else {
					columns = WIDTH;
				}
				break;
			default:
				columns = WIDTH;
				break;
			}

			snprintf(buffer, sizeof(buffer), "COLUMNS=%u", columns);
			putenv(strdup(buffer));

#ifdef __linux

			/*
			 * Some programs won't forward the environment variables anyway, so
			 * let's tell the kernel to reset cols and rows and maybe that will
			 * make it across.
			 *
			 * We use perror() here because it will make its way back to the
			 * parent (I hope).  We don't have control of the terminal anymore.
			 */
			struct winsize console_size;
			if (ioctl(STDIN_FILENO, TIOCGWINSZ, &console_size) < 0) {
				perror("ioctl(TIOCGWINSZ)");
			} else {
				console_size.ws_row = HEIGHT - STATUS_HEIGHT;
				console_size.ws_col = columns;
				if (ioctl(STDIN_FILENO, TIOCSWINSZ, &console_size) < 0) {
					perror("ioctl(TIOCSWINSZ)");
				}
			}

#endif /* __linux */

			/* Set the LANG */
			switch (target->emulation) {
			case Q_EMUL_XTERM_UTF8:
			case Q_EMUL_LINUX_UTF8:
				snprintf(buffer, sizeof(buffer), "LANG=%s", get_option(Q_OPTION_UTF8_LANG));
				putenv(strdup(buffer));
				break;
			default:
				snprintf(buffer, sizeof(buffer), "LANG=%s", get_option(Q_OPTION_ISO8859_LANG));
				putenv(strdup(buffer));
				break;
			}

			/* Separate target into arguments */
			target_argv = tokenize_command(command);
			Xfree(command, __FILE__, __LINE__);
			execvp(target_argv[0], target_argv);

		} else {

			/* Free leak */
			Xfree(command, __FILE__, __LINE__);
		}
	}

	/*
	 * Parent qodem process
	 */

	/* Don't block the port */
	set_nonblock(q_child_tty_fd);

	/* Set to raw mode */
	/* set_raw_termios(q_child_tty_fd); */

	/* Reset the bytes connection bytes counter */
	q_connection_bytes_received = 0;

	/* Reset the terminal emulation state */
	q_status.emulation = target->emulation;
	q_status.codepage = target->codepage;
	reset_emulation();

	/* Switch to doorway mode if requested */
	if (target->doorway == Q_DOORWAY_CONFIG) {
		if (strcasecmp(get_option(Q_OPTION_CONNECT_DOORWAY), "doorway") == 0) {
			q_status.doorway_mode = Q_DOORWAY_MODE_FULL;
		}
		if (strcasecmp(get_option(Q_OPTION_CONNECT_DOORWAY), "mixed") == 0) {
			q_status.doorway_mode = Q_DOORWAY_MODE_MIXED;
		}
	} else if (target->doorway == Q_DOORWAY_ALWAYS_DOORWAY) {
		q_status.doorway_mode = Q_DOORWAY_MODE_FULL;
	} else if (target->doorway == Q_DOORWAY_ALWAYS_MIXED) {
		q_status.doorway_mode = Q_DOORWAY_MODE_MIXED;
	} else if (target->doorway == Q_DOORWAY_NEVER) {
		q_status.doorway_mode = Q_DOORWAY_MODE_OFF;
	}
	/* Set remaining toggles */
	if (target->use_default_toggles == Q_FALSE) {
		set_dial_out_toggles(target->toggles);
	}

	if (target->method != Q_DIAL_METHOD_MODEM) {
		time(&q_status.connect_time);
		q_status.online = Q_TRUE;
		q_child_pid = child_pid;

		/*
		 * Untag it in the phonebook on the assumption
		 * we connected
		 */
		if (target->tagged == Q_TRUE) {
			target->tagged = Q_FALSE;
			q_phonebook.tagged--;
		}

		/* Log */
		qlog(_("CONNECTION ESTABLISHED: %ls\n"), target->name);

		/* Play connect sequence */
		if (q_status.beeps == Q_TRUE) {
			play_sequence(Q_MUSIC_CONNECT);
		}

		/* Go immediately to console */
		switch_state(Q_STATE_CONSOLE);

		/* Execute script if supplied */
		if (target->script_filename != NULL) {
			if (strlen(target->script_filename) > 0) {
				script_start(target->script_filename);
			}
		}
		
		screen_flush();
	}

	return q_child_tty_fd;
} /* ---------------------------------------------------------------------- */
